Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3889)

Unified Diff: chrome/browser/history/history_service.h

Issue 330603004: Rename FaviconBitmapXxx to FaviconRawBitmapXxx (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/history/history_service.h
diff --git a/chrome/browser/history/history_service.h b/chrome/browser/history/history_service.h
index c5fd133e82311492a5f94a5dfae7580e40e44046..c6c56ca144ec3d4b7114f5f9b9e5a2a96e4c3472 100644
--- a/chrome/browser/history/history_service.h
+++ b/chrome/browser/history/history_service.h
@@ -648,7 +648,7 @@ class HistoryService : public CancelableRequestProvider,
// which most closely match |desired_size_in_dip| x |desired_size_in_dip| and
// |desired_scale_factors| for |icon_types|. If |desired_size_in_dip| is 0,
// the largest favicon bitmap for |icon_types| is returned. The returned
- // FaviconBitmapResults will have at most one result for each of
+ // FaviconRawBitmapResults will have at most one result for each of
// |desired_scale_factors|. If a favicon bitmap is determined to be the best
// candidate for multiple scale factors there will be less results.
// If |icon_types| has several types, results for only a single type will be
@@ -665,7 +665,8 @@ class HistoryService : public CancelableRequestProvider,
// Used by the FaviconService to get favicons mapped to |page_url| for
// |icon_types| which most closely match |desired_size_in_dip| and
// |desired_scale_factors|. If |desired_size_in_dip| is 0, the largest favicon
- // bitmap for |icon_types| is returned. The returned FaviconBitmapResults will
+ // bitmap for |icon_types| is returned. The returned FaviconRawBitmapResults
+ // will
// have at most one result for each of |desired_scale_factors|. If a favicon
// bitmap is determined to be the best candidate for multiple scale factors
// there will be less results. If |icon_types| has several types, results for
@@ -694,7 +695,7 @@ class HistoryService : public CancelableRequestProvider,
const GURL& page_url,
const std::vector<int>& icon_types,
int minimum_size_in_pixels,
- const favicon_base::FaviconRawCallback& callback,
+ const favicon_base::FaviconRawBitmapCallback& callback,
base::CancelableTaskTracker* tracker);
// Used by the FaviconService to get the favicon bitmap which most closely
@@ -766,17 +767,17 @@ class HistoryService : public CancelableRequestProvider,
// backend.
// |favicon_bitmap_data| replaces all the favicon bitmaps mapped to
// |page_url|.
// |expired| and |icon_type| fields in FaviconBitmapData are ignored.
// Use MergeFavicon() if |favicon_bitmap_data| is incomplete, and favicon
// bitmaps in the database should be preserved if possible. For instance,
// favicon bitmaps from sync are 1x only. MergeFavicon() is used to avoid
// deleting the 2x favicon bitmap if it is present in the history backend.
// See HistoryBackend::ValidateSetFaviconsParams() for more details on the
// criteria for |favicon_bitmap_data| to be valid.
- void SetFavicons(
- const GURL& page_url,
- favicon_base::IconType icon_type,
- const std::vector<favicon_base::FaviconBitmapData>& favicon_bitmap_data);
+ void SetFavicons(const GURL& page_url,
+ favicon_base::IconType icon_type,
+ const std::vector<favicon_base::FaviconRawBitmapData>&
+ favicon_bitmap_data);
// Used by the FaviconService to mark the favicon for the page as being out
// of date.
@@ -766,17 +767,17 @@ class HistoryService : public CancelableRequestProvider,
// |favicon_bitmap_data| replaces all the favicon bitmaps mapped to
// |page_url|.
- // |expired| and |icon_type| fields in FaviconBitmapData are ignored.
+ // |expired| and |icon_type| fields in FaviconRawBitmapData are ignored.
// Use MergeFavicon() if |favicon_bitmap_data| is incomplete, and favicon
// bitmaps in the database should be preserved if possible. For instance,

Powered by Google App Engine
This is Rietveld 408576698